Page 29 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 29

Home

    were also secret movements organized for the purpose of
    undermining all moral and religious beliefs in the minds
    of Muslims. These began in the middle of the seventh
    century resulting in an immense schism in Islam that led
    to open warfare.

    An important faction to rise out of the many splits was
    the Ismailis who up to about A.D. 872 remained
    believers. At this time Abdullah ibn Maymun, an
    intriguer of extraordinary cunning, succeeded in
    capturing control of the movement which then became
    subversive, not only of Islamism, but of all religious
    beliefs. The Ismailis movement became a model for the

    organization of modern secret societies.

    The first open acts of violence resulting from the
    doctrines of Abdullah were carried out by the
    Karmathites, a secret society named after its leader
    Karmath. Karmath, a bora schemer who believed in
    nothing, became the leader of the Karmathites in Arabia

    society.

    Karmath persuaded his followers to give all of their
    money to him and establish a community of goods and
    wives. Becoming absolute master of their minds, he led
    them away from all religion and released them from all
    the duties of piety, devotion, and the fear of God. This
    was just the opposite of what he had prescribed for them
    before they were "enlightened."

    He permitted them pillage (robbery by violent means),
    and every sort of immoral license, teaching that they

    24

    The Secret Side of History

    where a number of Arabs were soon enlisted in the